# -*- coding: utf-8 -*-

from .AB440SA import AB440SA

__all__ = ["AB440SA"]
